@echo off
rem ****************************************************** {COPYRIGHT-TOP} ***
rem Licensed Materials - Property of IBM
rem 5724-M07, 5698-A77
rem
rem (C) Copyright IBM Corp. 2005,2006 All Rights Reserved.
rem
rem US Government Users Restricted Rights - Use, duplication, or
rem disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem ****************************************************** {COPYRIGHT-END} ***
set ERRORLEVEL=0
set ACTION=%1
set ENV_KEY=%2
set ENV_TYPE=%3
set ARG4=%4
set ARG5=%5
set ARG6=%6
set ARG7=%7

set KD4_HOME_PROPFILE=%SYSTEMROOT%\system32\drivers\etc\KD4BaseDirConfig.properties

rem check the mandatory keywords 

if "%ACTION%" == "-enable" goto check_env
if "%ACTION%" == "-disable" goto check_env
goto syntax

:check_env
if "%ENV_KEY%" == "-env" goto find_kd4_home
goto syntax

rem check if KD4_HOME_PROPFILE exists

:find_kd4_home
if exist %KD4_HOME_PROPFILE% goto kd4_home_dir_name_ok
echo Error: %KD4_HOME_PROPFILE% not found
set KD4_RC=111
goto done

rem 1. read the properties file into an env var.  this should be:
rem     INSTALLDIR=install_location
rem 2. create a temp bat file with "set INSTALLDIR=install_location
rem 3. run the temp bat file to set the INSTALLDIR env var
rem 4. erase the temp bat file
rem
:kd4_home_dir_name_ok

rem following line sets INSTALLDIR_PROP to contents of the prop file
set /p INSTALLDIR_PROP= <  %KD4_HOME_PROPFILE%

rem following line prepends the word "set" to the line read above
rem and writes the result to a temp bat file
echo set %INSTALLDIR_PROP%> %TEMP%\KD4SET.BAT

call %TEMP%\KD4SET.BAT
del %TEMP%\KD4SET.BAT

rem INSTALLDIR now contains the KD4 home dir location.  make sure it exists
if exist %INSTALLDIR% goto kd4_home_dir_ok
if exist "%INSTALLDIR%" goto kd4_home_dir_ok

echo Error: %INSTALLDIR% not found
set KD4_RC=111
goto done

rem Call the appropriate script based on ENV_TYPE
:kd4_home_dir_ok

echo KD4 Home Dir =  %INSTALLDIR%
if %ENV_TYPE% == 1 goto call_WAS_script
if %ENV_TYPE% == 2 goto call_NET_script
if %ENV_TYPE% == 3 goto call_BEA_script
if %ENV_TYPE% == 4 goto call_JBOSS_script
if %ENV_TYPE% == 8 goto call_DP_script
if %ENV_TYPE% == 9 goto call_SCA_script

goto syntax

rem Check args and call the WAS script
:call_WAS_script

if "%ACTION%" == "" goto WAS_syntax
rem make sure there is no %ARG5% - that indicates unquoted dir name
for /f "usebackq delims==" %%v in (`set`) do if %%v == ARG5 goto WAS_syntax 

rem check if %ARG4% was ever set
for /f "usebackq delims==" %%v in (`set`) do if %%v == ARG4 goto set_WAS_cmd 

set ARG4=USE_ENV_VAR
goto set_WAS_cmd

:set_WAS_cmd
if %ARG4% == -h goto WAS_syntax
set cmd="%INSTALLDIR%"\KD4\bin\configWASDC.BAT %ACTION% %ARG4% 
echo Configuration command = %CMD%
call %cmd%

set KD4_RC=%ERRORLEVEL%
echo Return code from configWASDC.bat = %KD4_RC%
goto done

rem Check args and call the NET script
:call_NET_script
set cmd=%INSTALLDIR%\KD4\bin\configNETDC.BAT %ACTION% %INSTALLDIR%
echo Configuration command = %CMD%
call %cmd%
set KD4_RC=%ERRORLEVEL%
echo Return code from configNETDC.bat = %KD4_RC%
goto done

rem Check args and call the BEA script
:call_BEA_script
if "%ARG6%" == "" goto BEA_syntax
set cmd=%INSTALLDIR%\KD4\bin\configBEADC.BAT %ACTION% %ARG4% %ARG5% %ARG6% %INSTALLDIR%
echo Configuration command = %CMD%
call %cmd%
set KD4_RC=%ERRORLEVEL%
echo Return code from configBEADC.bat = %KD4_RC%
goto done

rem add by yushiwei
rem Check args and call the JBOSS script
:call_JBOSS_script
rem make sure there is no %ARG6% - that indicates unquoted dir name
for /f "usebackq delims==" %%v in (`set`) do if %%v == ARG6 goto JBoss_syntax 	
rem check if %ARG5% was ever set
for /f "usebackq delims==" %%v in (`set`) do if %%v == ARG5 goto set_JBOSS_cmd
set ARG5=USE_ENV_HOME

rem check if %ARG4% was ever set
if "%ARG4%" == "" goto JBOSS_syntax
goto set_JBOSS_cmd

:set_JBOSS_cmd
if %ARG5% == -h goto JBOSS_syntax
set cmd="%INSTALLDIR%"\KD4\bin\configJBOSSDC.BAT %ACTION% %ARG4% %ARG5% %INSTALLDIR%
echo Configuration command = %CMD%
call %cmd%
set KD4_RC=%ERRORLEVEL%
echo Return code from configJBOSSDC.bat = %KD4_RC%
goto done

rem Check args and call the DataPower script
:call_DP_script
if "%ARG7%" =="" goto DP_syntax
rem DP can have up to 8 key/value pairs for a total of 16 args.  Windows only
rem allows 10 args at a time.   Need to use shift to access all args.   We 
rem will access 20 to be safe.  First, shift off the first 4  args.
shift & shift & shift & shift
set KEY_VALUE_SET1=%0 %1 %2 %3 %4 %5 %6 %7 %8 %9
shift & shift & shift & shift & shift & shift & shift & shift & shift & shift
set KEY_VALUE_SET2=%0 %1 %2 %3 %4 %5 %6 %7 %8 %9

rem strip double quotes

set KEY_VALUE_SET1=%KEY_VALUE_SET1:"=%
set KEY_VALUE_SET2=%KEY_VALUE_SET2:"=%

set PROP_FILE=%INSTALLDIR%\KD4\config\KD4.dpdcConfig.properties
set cmd=%INSTALLDIR%\KD4\bin\configDPDC.bat %ACTION% %INSTALLDIR% %PROP_FILE% "%KEY_VALUE_SET1% %KEY_VALUE_SET2%"
echo Configuration command = %CMD%
call %cmd%
set KD4_RC=%ERRORLEVEL%
echo Return code from configDPDC.bat = %KD4_RC%
goto done

rem Check args and call the SCA script
:call_SCA_script

if "%ACTION%" == "" goto SCA_syntax
rem make sure there is no %ARG5% - that indicates unquoted dir name
for /f "usebackq delims==" %%v in (`set`) do if %%v == ARG5 goto WAS_syntax 

rem check if %ARG4% was ever set
for /f "usebackq delims==" %%v in (`set`) do if %%v == ARG4 goto set_SCA_cmd 

set ARG4=USE_ENV_VAR
goto set_SCA_cmd

:set_SCA_cmd
if %ARG4% == -h goto SCA_syntax
set cmd="%INSTALLDIR%"\KD4\bin\configSCADC.BAT %ACTION% %ARG4% 
echo Configuration command = %CMD%
call %cmd%

set KD4_RC=%ERRORLEVEL%
echo Return code from configSCADC.bat = %KD4_RC%
goto done

:syntax
echo "Usage: KD4configDC.bat [-enable|-disable] -env [1|2|3|4|8|9] <server_specific_options>"
echo    Application server environments:
echo       1 = IBM WebSphere Application Server
echo       2 = Microsoft ASP.NET
echo       3 = BEA WebLogic Server
echo       4 = JBoss Application Server
echo       8 = DataPower
echo       9 = Service Component Architecture (SCA) monitoring in WESB and WPS
set KD4_RC=100
goto done

:WAS_syntax
echo "Usage: KD4configDC.bat [-enable|-disable] -env 1 <WAS_HOME>"
set KD4_RC=100
goto done

:BEA_syntax
echo "Usage: KD4configDC.bat [-enable|-disable] -env 3 <URL> <userid> <password>"
set KD4_RC=100
goto done

:JBOSS_syntax
echo "Usage: KD4configDC.bat [-enable|-disable] -env 4 <server_name> <JBOSS_HOME>"
echo    JBoss Application server configurations:
echo       server_name : Name of server need to be configured
echo       JBOSS_HOME : The path name where JBOSS installed into, optional. If user already exported the JBOSS_HOME into environment, it's not required. Otherwise, user must provide that when running the script.
set KD4_RC=100
goto done

:DP_syntax
echo "Usage: KD4configDC.bat [-enable|-disable] -env 8 -host hostName -user userName (-pswd password -port port -path urlPath -poll pollInterval -domainlist "domain1,domain2,..." -displaygroup groupName)"
set KD4_RC=100
goto done

:SCA_syntax
echo "Usage: KD4configDC.bat [-enable|-disable] -env 9 (<WESB_HOME> | <WPS_HOME>)"
set KD4_RC=100
goto done


:done
set ERRORLEVEL=%KD4_RC%
